NIFValidatorResponse class
- Inheritance
-
- Object
- NIFValidatorResult
- NIFValidatorResponse
Constructors
- NIFValidatorResponse({required String nif, required String name, String? nomeSede, String? mensagemRetorno, int? situacaoNIFAGT, String? bairro, String? comuna, String? rua, String? municipio, String? municipioId, String? provincia, String? provinciaId, String? tipoContribuinte, bool? cadastradoNo3s})
-
NIFValidatorResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bairro → String?
-
final
- cadastradoNo3s → bool?
-
final
- comuna → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
finalinherited
- mensagemRetorno → String?
-
final
- municipio → String?
-
final
- municipioId → String?
-
final
- name → String
-
final
- nif → String
-
final
- nomeSede → String?
-
final
- provincia → String?
-
final
- provinciaId → String?
-
final
- rua → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- situacaoNIFAGT → int?
-
final
- tipoContribuinte → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited